@@ -464,6 +464,11 @@ echo ""
 echo "======================================"
 echo "Setting up WebSocket Terminal Server..."
 
+# Install build dependencies for node-pty
+echo "Installing build dependencies..."
+dnf groupinstall -y "Development Tools"
+dnf install -y python3-devel
+
 # Install Node.js via NVM if not present
 if ! command -v node &> /dev/null; then
     echo "Installing Node.js 22 LTS via NVM..."
